@@ -27,6 +27,16 @@
 #include <linux/string.h>
 #include <linux/completion.h>
 #include <linux/module.h>
+#include <linux/cpumask.h>
+#include <linux/mm.h>
+
+// If NV_BUILD_MODULE_INSTANCES is not defined, do it here in order to avoid
+// build warnings/errors when including nv-linux.h as it expects the definition
+// to be present.
+#ifndef NV_BUILD_MODULE_INSTANCES
+#define NV_BUILD_MODULE_INSTANCES 1
+#endif
+#include "nv-linux.h"
 
 // Below are just a very few lines of printing and test assertion support.
 // It is important to avoid dependencies on other modules, because nv-kthread-q
@@ -419,6 +429,79 @@ static int _same_q_item_test(void)
     return 0;
 }
 
+static void _check_cpu_affinity_callback(void *args)
+{
+    struct task_struct *thread = get_current();
+    struct page *stack;
+    int *stack_allocation_node = (int *)args;
+
+    // As of kernel 4.9 (commit ba14a194a434c "fork: Add generic vmalloced stack
+    // support"), it is possible for kthread stacks to be allocated using vmalloc.
+    // Luckily, the calls to detect vmalloc'ed addresses and to translate a
+    // vmalloc'ed address to a struct page are present and exported in all kernels
+    // we care about. Therefore, no special treatment is needed for kernels older
+    // than 4.9.
+    if (is_vmalloc_addr(thread->stack))
+        stack = vmalloc_to_page(thread->stack);
+    else
+        stack = virt_to_page(thread->stack);
+    *stack_allocation_node = page_to_nid(stack);
+}
+
+static int _check_cpu_affinity_test(void)
+{
+    int result, i, stack_allocation_node;
+    nv_kthread_q_t local_q;
+    nv_kthread_q_item_t q_item;
+    char q_name[64];
+    int node;
+
+    // If the API does not support CPU affinity, check whether the correct
+    // error code is returned.
+    // Non-affinitized queue allocation has been verified by previous test
+    // so just ensure that the affinitized version also works.
+    if (!NV_KTHREAD_Q_SUPPORTS_AFFINITY()) {
+        result = nv_kthread_q_init_on_node(&local_q, "should_fail", 0);
+        TEST_CHECK_RET(result == -ENOTSUPP);
+        return 0;
+    }
+
+    for_each_online_node(node) {
+
+        // Only test on nodes which have memory
+        if (nv_numa_node_has_memory(node))
+            continue;
+
+        nv_kthread_q_item_init(&q_item, _check_cpu_affinity_callback, &stack_allocation_node);
+        snprintf(q_name, sizeof(q_name), "test_q_%d", node);
+        result = nv_kthread_q_init_on_node(&local_q, q_name, node);
+        TEST_CHECK_RET(result == 0);
+
+        // Run just several iterations to ensure that the callback is run.
+        //
+        // This loop can't use the TEST_CHECK_RET() macro as it includes a
+        // return statement, which will prevent the cleanup.
+        for (i = 0; i < 100; i++) {
+            stack_allocation_node = -1;
+            result = nv_kthread_q_schedule_q_item(&local_q, &q_item);
+            if (!result)
+                break;
+            nv_kthread_q_flush(&local_q);
+            if (stack_allocation_node != node) {
+                result = 0;
+                break;
+            }
+        }
+        nv_kthread_q_stop(&local_q);
+
+        // nv_kthread_q_schedule_q_item() returns non-zero value if the item was
+        // successfully scheduled. Therefore, if the loop above executed correctly,
+        // the value of result here should not be 0.
+        TEST_CHECK_RET(result != 0);
+    }
+    return 0;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Top-level test entry point
 
@@ -438,5 +521,8 @@ int nv_kthread_q_run_self_test(void)
     result = _same_q_item_test();
     TEST_CHECK_RET(result == 0);
 
+    result = _check_cpu_affinity_test();
+    TEST_CHECK_RET(result == 0);
+
     return 0;
 }
