@@ -66,7 +66,7 @@ static NV_STATUS check_reverse_map_block_page(uvm_va_block_t *va_block,
             TEST_CHECK_RET(nv_kref_read(&va_block->kref) >= 2);
             TEST_CHECK_RET(uvm_reverse_map_start(&g_sysmem_translations[0]) == uvm_va_block_cpu_page_address(va_block, page_index));
             TEST_CHECK_RET(uvm_va_block_region_num_pages(g_sysmem_translations[0].region) == 1);
-            TEST_CHECK_RET(g_sysmem_translations[0].owner == UVM_CPU_ID);
+            TEST_CHECK_RET(UVM_ID_IS_CPU(g_sysmem_translations[0].owner));
             uvm_va_block_release(g_sysmem_translations[0].va_block);
         }
         else {
@@ -109,7 +109,7 @@ static NV_STATUS check_reverse_map_block_batch(uvm_va_block_t *va_block,
         TEST_CHECK_RET(reverse_map->va_block == va_block);
         TEST_CHECK_RET(nv_kref_read(&va_block->kref) >= 2);
         uvm_va_block_release(reverse_map->va_block);
-        TEST_CHECK_RET(reverse_map->owner == UVM_CPU_ID);
+        TEST_CHECK_RET(UVM_ID_IS_CPU(reverse_map->owner));
     }
 
     if (page_mask)
@@ -123,11 +123,11 @@ static NV_STATUS check_reverse_map_block_batch(uvm_va_block_t *va_block,
 // Check that the DMA addresses for all the CPU pages of the two given VA blocks
 // are registered in the reverse map, using a single translation call. The
 // returned virtual addresses must belong to one of the blocks. The function
-// assumes a 1:1 dma-to-virt mapping for each VA block and that va_block2 is
-// mapped behind va_block1.
+// assumes a 1:1 dma-to-virt mapping for each VA block and that va_block1 is
+// mapped behind va_block0.
 static NV_STATUS check_reverse_map_two_blocks_batch(NvU64 base_dma_addr,
-                                                    uvm_va_block_t *va_block1,
-                                                    uvm_va_block_t *va_block2)
+                                                    uvm_va_block_t *va_block0,
+                                                    uvm_va_block_t *va_block1)
 {
     size_t num_pages;
     size_t num_translations;
@@ -149,21 +149,21 @@ static NV_STATUS check_reverse_map_two_blocks_batch(NvU64 base_dma_addr,
         size_t num_reverse_map_pages = uvm_va_block_region_num_pages(reverse_map->region);
 
         if (reverse_map_index == 0)
-            block = va_block1;
+            block = va_block0;
         else
-            block = va_block2;
+            block = va_block1;
 
         TEST_CHECK_RET(reverse_map->va_block == block);
         TEST_CHECK_RET(nv_kref_read(&block->kref) >= 2);
         uvm_va_block_release(reverse_map->va_block);
         TEST_CHECK_RET(num_reverse_map_pages == uvm_va_block_num_cpu_pages(block));
         TEST_CHECK_RET(virt_addr == block->start);
-        TEST_CHECK_RET(reverse_map->owner == UVM_CPU_ID);
+        TEST_CHECK_RET(UVM_ID_IS_CPU(reverse_map->owner));
 
         num_pages += num_reverse_map_pages;
     }
 
-    TEST_CHECK_RET(num_pages == uvm_va_block_num_cpu_pages(va_block1) + uvm_va_block_num_cpu_pages(va_block2));
+    TEST_CHECK_RET(num_pages == uvm_va_block_num_cpu_pages(va_block0) + uvm_va_block_num_cpu_pages(va_block1));
 
     return NV_OK;
 }
@@ -192,7 +192,7 @@ static NV_STATUS test_pmm_sysmem_reverse_map_single(uvm_va_block_t *va_block,
                                                          va_block->start + subregion.first * PAGE_SIZE,
                                                          uvm_va_block_region_size(subregion),
                                                          va_block,
-                                                         UVM_CPU_ID);
+                                                         UVM_ID_CPU);
         uvm_mutex_unlock(&va_block->lock);
         if (status != NV_OK)
             return status;
@@ -318,26 +318,36 @@ static NV_STATUS test_pmm_sysmem_reverse_map_single_pattern(uvm_va_space_t *va_s
 static NV_STATUS test_pmm_sysmem_reverse_map_many_blocks(uvm_va_space_t *va_space, NvU64 addr)
 {
     NV_STATUS status;
+    uvm_va_block_t *va_block0;
     uvm_va_block_t *va_block1;
-    uvm_va_block_t *va_block2;
+    NvU64 base_dma_addr0;
     NvU64 base_dma_addr1;
-    NvU64 base_dma_addr2;
 
-    status = uvm_va_block_find(va_space, addr + UVM_VA_BLOCK_SIZE / 4, &va_block1);
+    status = uvm_va_block_find(va_space, addr + UVM_VA_BLOCK_SIZE / 4, &va_block0);
     if (status != NV_OK)
         return status;
 
-    status = uvm_va_block_find(va_space, addr + 3 * UVM_VA_BLOCK_SIZE / 4, &va_block2);
+    status = uvm_va_block_find(va_space, addr + 3 * UVM_VA_BLOCK_SIZE / 4, &va_block1);
     if (status != NV_OK)
         return status;
 
-    TEST_CHECK_RET(va_block1 != va_block2);
+    TEST_CHECK_RET(va_block0 != va_block1);
 
-    base_dma_addr1 = g_base_dma_addr + uvm_va_block_size(va_block1);
-    base_dma_addr2 = base_dma_addr1 + uvm_va_block_size(va_block1);
+    base_dma_addr0 = g_base_dma_addr + uvm_va_block_size(va_block0);
+    base_dma_addr1 = base_dma_addr0 + uvm_va_block_size(va_block0);
 
+    TEST_CHECK_RET(is_power_of_2(uvm_va_block_size(va_block0)));
     TEST_CHECK_RET(is_power_of_2(uvm_va_block_size(va_block1)));
-    TEST_CHECK_RET(is_power_of_2(uvm_va_block_size(va_block2)));
+
+    uvm_mutex_lock(&va_block0->lock);
+    status = uvm_pmm_sysmem_mappings_add_gpu_mapping(&g_reverse_map,
+                                                     base_dma_addr0,
+                                                     va_block0->start,
+                                                     uvm_va_block_size(va_block0),
+                                                     va_block0,
+                                                     UVM_ID_CPU);
+    uvm_mutex_unlock(&va_block0->lock);
+    TEST_CHECK_RET(status == NV_OK);
 
     uvm_mutex_lock(&va_block1->lock);
     status = uvm_pmm_sysmem_mappings_add_gpu_mapping(&g_reverse_map,
@@ -345,38 +355,28 @@ static NV_STATUS test_pmm_sysmem_reverse_map_many_blocks(uvm_va_space_t *va_spac
                                                      va_block1->start,
                                                      uvm_va_block_size(va_block1),
                                                      va_block1,
-                                                     UVM_CPU_ID);
+                                                     UVM_ID_CPU);
     uvm_mutex_unlock(&va_block1->lock);
-    TEST_CHECK_RET(status == NV_OK);
-
-    uvm_mutex_lock(&va_block2->lock);
-    status = uvm_pmm_sysmem_mappings_add_gpu_mapping(&g_reverse_map,
-                                                     base_dma_addr2,
-                                                     va_block2->start,
-                                                     uvm_va_block_size(va_block2),
-                                                     va_block2,
-                                                     UVM_CPU_ID);
-    uvm_mutex_unlock(&va_block2->lock);
 
     // Check each VA block individually
     if (status == NV_OK) {
+        TEST_CHECK_GOTO(check_reverse_map_block_page(va_block0, base_dma_addr0, NULL) == NV_OK, error);
+        TEST_CHECK_GOTO(check_reverse_map_block_batch(va_block0, base_dma_addr0, NULL) == NV_OK, error);
         TEST_CHECK_GOTO(check_reverse_map_block_page(va_block1, base_dma_addr1, NULL) == NV_OK, error);
         TEST_CHECK_GOTO(check_reverse_map_block_batch(va_block1, base_dma_addr1, NULL) == NV_OK, error);
-        TEST_CHECK_GOTO(check_reverse_map_block_page(va_block2, base_dma_addr2, NULL) == NV_OK, error);
-        TEST_CHECK_GOTO(check_reverse_map_block_batch(va_block2, base_dma_addr2, NULL) == NV_OK, error);
 
         // Check both VA blocks at the same time
-        TEST_CHECK_GOTO(check_reverse_map_two_blocks_batch(g_base_dma_addr, va_block1, va_block2) == NV_OK, error);
+        TEST_CHECK_GOTO(check_reverse_map_two_blocks_batch(g_base_dma_addr, va_block0, va_block1) == NV_OK, error);
 
 error:
-        uvm_mutex_lock(&va_block2->lock);
-        uvm_pmm_sysmem_mappings_remove_gpu_mapping(&g_reverse_map, base_dma_addr2);
-        uvm_mutex_unlock(&va_block2->lock);
+        uvm_mutex_lock(&va_block1->lock);
+        uvm_pmm_sysmem_mappings_remove_gpu_mapping(&g_reverse_map, base_dma_addr1);
+        uvm_mutex_unlock(&va_block1->lock);
     }
 
-    uvm_mutex_lock(&va_block1->lock);
-    uvm_pmm_sysmem_mappings_remove_gpu_mapping(&g_reverse_map, base_dma_addr1);
-    uvm_mutex_unlock(&va_block1->lock);
+    uvm_mutex_lock(&va_block0->lock);
+    uvm_pmm_sysmem_mappings_remove_gpu_mapping(&g_reverse_map, base_dma_addr0);
+    uvm_mutex_unlock(&va_block0->lock);
 
     return status;
 }
@@ -422,7 +422,7 @@ static NV_STATUS test_pmm_sysmem_reverse_map_merge(uvm_va_space_t *va_space, NvU
                                                              uvm_va_block_cpu_page_address(va_block, page_index),
                                                              PAGE_SIZE,
                                                              va_block,
-                                                             UVM_CPU_ID);
+                                                             UVM_ID_CPU);
             uvm_mutex_unlock(&va_block->lock);
             TEST_CHECK_RET(status == NV_OK);
 
@@ -436,7 +436,7 @@ static NV_STATUS test_pmm_sysmem_reverse_map_merge(uvm_va_space_t *va_space, NvU
                                                          uvm_va_block_cpu_page_address(va_block, page_index),
                                                          UVM_CHUNK_SIZE_64K,
                                                          va_block,
-                                                         UVM_CPU_ID);
+                                                         UVM_ID_CPU);
         uvm_mutex_unlock(&va_block->lock);
         TEST_CHECK_RET(status == NV_OK);
 
@@ -451,7 +451,7 @@ static NV_STATUS test_pmm_sysmem_reverse_map_merge(uvm_va_space_t *va_space, NvU
                                                          uvm_va_block_cpu_page_address(va_block, page_index),
                                                          PAGE_SIZE,
                                                          va_block,
-                                                         UVM_CPU_ID);
+                                                         UVM_ID_CPU);
         uvm_mutex_unlock(&va_block->lock);
         TEST_CHECK_RET(status == NV_OK);
 
@@ -493,7 +493,7 @@ static NV_STATUS test_pmm_sysmem_reverse_map_remove_on_eviction(uvm_va_space_t *
                                                      addr,
                                                      uvm_va_block_size(va_block),
                                                      va_block,
-                                                     UVM_CPU_ID);
+                                                     UVM_ID_CPU);
     uvm_mutex_unlock(&va_block->lock);
 
     uvm_mutex_lock(&va_block->lock);
