@@ -162,6 +162,7 @@ static void nv_p2p_free_dma_mapping(
 
     os_mem_set(peer_nvl, 0, sizeof(nv_linux_state_t));
 
+    peer_nvl->dev = &dma_mapping->pci_dev->dev;
     peer_nvl->pci_dev = dma_mapping->pci_dev;
 
     peer_nv = NV_STATE_PTR(peer_nvl);
@@ -614,6 +615,7 @@ int nvidia_p2p_dma_map_pages(
 
     os_mem_set(peer_nvl, 0, sizeof(nv_linux_state_t));
 
+    peer_nvl->dev = &peer->dev;
     peer_nvl->pci_dev = peer;
 
     peer_nv = NV_STATE_PTR(peer_nvl);
