@@ -1365,6 +1365,15 @@ NvBool NV_API_CALL os_is_grid_supported(void)
 #endif
 }
 
+NvU32 NV_API_CALL os_get_grid_csp_support(void)
+{
+#if defined(NV_GRID_BUILD_CSP)
+    return NV_GRID_BUILD_CSP;
+#else
+    return 0;
+#endif
+}
+
 void NV_API_CALL os_bug_check(NvU32 bugCode, const char *bugCodeStr)
 {
     panic(bugCodeStr);
